@@ -247,6 +247,23 @@ class ezfuc(object):
             return text
         return text
 
+    @staticmethod
+    def check_content(old_data, new_data):
+        """
+        检查两个列表内容是否一致，与位置无关
+        """
+        if isinstance(ezfuc.get_first(old_data), dict):
+            old_data_md5 = [ezfuc.md5(i.values()) for i in old_data]
+            new_data_md5 = [ezfuc.md5(i.values()) for i in new_data]
+        else:
+            old_data_md5 = [ezfuc.md5(i) for i in old_data]
+            new_data_md5 = [ezfuc.md5(i) for i in new_data]
+        check_list = list(set(old_data_md5 + new_data_md5))
+        if len(check_list) == len(old_data_md5):
+            return True
+        else:
+            return False
+
     @staticmethod
     def random_ua():
         """
